# NAGINI-3D | Prediction of Parametric Surfaces for Multi-Object Segmentation in 3D Biological Imaging

We present NAGINI-3D (N-Active shapes for seGmentINg 3D biological Images), a method dedicated to 3D biological images segmentation, based on both deep learning (CNN) and Active Surfaces (Snakes).

This package implement the method described in:

- Quentin RAPILLY, Anaïs BADOUAL,Pierre MAINDRON, Guenaelle BOUET, Charles KERVRANN.
*Prediction of Parametric Surfaces for Multi-Object Segmentation in 3D Biological Imaging*.
Scale Space and Variational Methods in Computer Vision. SSVM 2025. Lecture Notes in Computer Science, vol 15667, Devon, UK, May 2025,
[(preprint)](https://hal.science/hal-04978619), [(final paper)](https://link.springer.com/chapter/10.1007/978-3-031-92366-1_20).

All details on the implementation and the tutorials are available on [the github of the project.](https://github.com/QuentinRapilly/NAGINI-3D)

## Versions

### 0.1.1

**Anisotropic version:** option to process highly anisotropic images.

### 0.0.2

**Paper version**: code used to assess our method for SSVM submission.

### 0.0.1

**Test version**: first pypi version.
